# This file was auto-generated by Fern from our API Definition.

import urllib.parse
from json.decoder import JSONDecodeError

import httpx
import pydantic

from ...core.api_error import ApiError
from ...core.remove_none_from_headers import remove_none_from_headers
from ...environment import VellumEnvironment
from ...types.model_version_read import ModelVersionRead


class ModelVersionsClient:
    def __init__(self, *, environment: VellumEnvironment = VellumEnvironment.PRODUCTION, api_key: str):
        self._environment = environment
        self.api_key = api_key

    def retrieve(self, id: str) -> ModelVersionRead:
        _response = httpx.request(
            "GET",
            urllib.parse.urljoin(f"{self._environment.default}/", f"v1/model-versions/{id}"),
            headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ModelVersionRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncModelVersionsClient:
    def __init__(self, *, environment: VellumEnvironment = VellumEnvironment.PRODUCTION, api_key: str):
        self._environment = environment
        self.api_key = api_key

    async def retrieve(self, id: str) -> ModelVersionRead:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "GET",
                urllib.parse.urljoin(f"{self._environment.default}/", f"v1/model-versions/{id}"),
                headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
                timeout=None,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ModelVersionRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class TypeEnum(str, enum.Enum):
    TEXT = "TEXT"
    CHAT_HISTORY = "CHAT_HISTORY"

    def visit(self, text: typing.Callable[[], T_Result], chat_history: typing.Callable[[], T_Result]) -> T_Result:
        if self is TypeEnum.TEXT:
            return text()
        if self is TypeEnum.CHAT_HISTORY:
            return chat_history()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ModelTypeEnum(str, enum.Enum):
    GENERATE = "GENERATE"
    CLASSIFY = "CLASSIFY"

    def visit(self, generate: typing.Callable[[], T_Result], classify: typing.Callable[[], T_Result]) -> T_Result:
        if self is ModelTypeEnum.GENERATE:
            return generate()
        if self is ModelTypeEnum.CLASSIFY:
            return classify()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .finish_reason_enum import FinishReasonEnum
from .normalized_log_probs import NormalizedLogProbs


class EnrichedNormalizedCompletion(pydantic.BaseModel):
    id: str = pydantic.Field(description=("The Vellum-generated ID of the completion.\n"))
    external_id: typing.Optional[str] = pydantic.Field(
        description=(
            "The external ID that was originally provided along with the generation request, which uniquely identifies this generation in an external system.\n"
        )
    )
    text: str = pydantic.Field(description=("The text generated by the LLM.\n"))
    finish_reason: typing.Optional[FinishReasonEnum] = pydantic.Field(
        description=("The reason the generation finished.\n")
    )
    logprobs: typing.Optional[NormalizedLogProbs] = pydantic.Field(
        description=("The logprobs of the completion. Only present if specified in the original request options.\n")
    )
    model_version_id: str = pydantic.Field(
        description=("The ID of the model version used to generate this completion.\n")
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ChatMessageRole(str, enum.Enum):
    SYSTEM = "SYSTEM"
    ASSISTANT = "ASSISTANT"
    USER = "USER"

    def visit(
        self,
        system: typing.Callable[[], T_Result],
        assistant: typing.Callable[[], T_Result],
        user: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ChatMessageRole.SYSTEM:
            return system()
        if self is ChatMessageRole.ASSISTANT:
            return assistant()
        if self is ChatMessageRole.USER:
            return user()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .model_type_enum import ModelTypeEnum
from .model_version_build_config import ModelVersionBuildConfig
from .model_version_exec_config_read import ModelVersionExecConfigRead
from .model_version_read_status_enum import ModelVersionReadStatusEnum
from .provider_enum import ProviderEnum


class ModelVersionRead(pydantic.BaseModel):
    id: str = pydantic.Field(description=("Vellum-generated ID that uniquely identifies this model version.\n"))
    created: str = pydantic.Field(description=("Timestamp of when this model version was created.\n"))
    label: str = pydantic.Field(description=("Human-friendly name for this model version.\n"))
    model_type: ModelTypeEnum = pydantic.Field(description=("The type of task this model is used for.\n"))
    provider: ProviderEnum = pydantic.Field(description=("Which LLM provider this model version is associated with.\n"))
    external_id: str = pydantic.Field(
        description=("The unique id of this model version as it exists in the above provider's system.\n")
    )
    build_config: ModelVersionBuildConfig = pydantic.Field(
        description=("Configuration used to build this model version.\n")
    )
    exec_config: ModelVersionExecConfigRead = pydantic.Field(
        description=("Configuration used to execute this model version.\n")
    )
    status: typing.Optional[ModelVersionReadStatusEnum]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

import httpx
import pydantic
from backports.cached_property import cached_property

from .core.api_error import ApiError
from .core.jsonable_encoder import jsonable_encoder
from .core.remove_none_from_headers import remove_none_from_headers
from .environment import VellumEnvironment
from .resources.documents.client import AsyncDocumentsClient, DocumentsClient
from .resources.model_versions.client import AsyncModelVersionsClient, ModelVersionsClient
from .resources.sandboxes.client import AsyncSandboxesClient, SandboxesClient
from .types.generate_options_request import GenerateOptionsRequest
from .types.generate_request import GenerateRequest
from .types.generate_response import GenerateResponse
from .types.search_request_options_request import SearchRequestOptionsRequest
from .types.search_response import SearchResponse
from .types.submit_completion_actual_request import SubmitCompletionActualRequest


class Vellum:
    def __init__(self, *, environment: VellumEnvironment = VellumEnvironment.PRODUCTION, api_key: str):
        self._environment = environment
        self.api_key = api_key

    def generate(
        self,
        *,
        deployment_id: typing.Optional[str] = None,
        deployment_name: typing.Optional[str] = None,
        requests: typing.List[GenerateRequest],
        options: typing.Optional[GenerateOptionsRequest] = None,
    ) -> GenerateResponse:
        _response = httpx.request(
            "POST",
            urllib.parse.urljoin(f"{self._environment.predict}/", "v1/generate"),
            json=jsonable_encoder(
                {
                    "deployment_id": deployment_id,
                    "deployment_name": deployment_name,
                    "requests": requests,
                    "options": options,
                }
            ),
            headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(GenerateResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def search(
        self,
        *,
        index_id: typing.Optional[str] = None,
        index_name: typing.Optional[str] = None,
        query: str,
        options: typing.Optional[SearchRequestOptionsRequest] = None,
    ) -> SearchResponse:
        _response = httpx.request(
            "POST",
            urllib.parse.urljoin(f"{self._environment.predict}/", "v1/search"),
            json=jsonable_encoder({"index_id": index_id, "index_name": index_name, "query": query, "options": options}),
            headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(SearchResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def submit_completion_actuals(
        self,
        *,
        deployment_id: typing.Optional[str] = None,
        deployment_name: typing.Optional[str] = None,
        actuals: typing.List[SubmitCompletionActualRequest],
    ) -> None:
        _response = httpx.request(
            "POST",
            urllib.parse.urljoin(f"{self._environment.predict}/", "v1/submit-completion-actuals"),
            json=jsonable_encoder(
                {"deployment_id": deployment_id, "deployment_name": deployment_name, "actuals": actuals}
            ),
            headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    @cached_property
    def documents(self) -> DocumentsClient:
        return DocumentsClient(environment=self._environment, api_key=self.api_key)

    @cached_property
    def model_versions(self) -> ModelVersionsClient:
        return ModelVersionsClient(environment=self._environment, api_key=self.api_key)

    @cached_property
    def sandboxes(self) -> SandboxesClient:
        return SandboxesClient(environment=self._environment, api_key=self.api_key)


class AsyncVellum:
    def __init__(self, *, environment: VellumEnvironment = VellumEnvironment.PRODUCTION, api_key: str):
        self._environment = environment
        self.api_key = api_key

    async def generate(
        self,
        *,
        deployment_id: typing.Optional[str] = None,
        deployment_name: typing.Optional[str] = None,
        requests: typing.List[GenerateRequest],
        options: typing.Optional[GenerateOptionsRequest] = None,
    ) -> GenerateResponse:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "POST",
                urllib.parse.urljoin(f"{self._environment.predict}/", "v1/generate"),
                json=jsonable_encoder(
                    {
                        "deployment_id": deployment_id,
                        "deployment_name": deployment_name,
                        "requests": requests,
                        "options": options,
                    }
                ),
                headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
                timeout=None,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(GenerateResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def search(
        self,
        *,
        index_id: typing.Optional[str] = None,
        index_name: typing.Optional[str] = None,
        query: str,
        options: typing.Optional[SearchRequestOptionsRequest] = None,
    ) -> SearchResponse:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "POST",
                urllib.parse.urljoin(f"{self._environment.predict}/", "v1/search"),
                json=jsonable_encoder(
                    {"index_id": index_id, "index_name": index_name, "query": query, "options": options}
                ),
                headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
                timeout=None,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(SearchResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def submit_completion_actuals(
        self,
        *,
        deployment_id: typing.Optional[str] = None,
        deployment_name: typing.Optional[str] = None,
        actuals: typing.List[SubmitCompletionActualRequest],
    ) -> None:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "POST",
                urllib.parse.urljoin(f"{self._environment.predict}/", "v1/submit-completion-actuals"),
                json=jsonable_encoder(
                    {"deployment_id": deployment_id, "deployment_name": deployment_name, "actuals": actuals}
                ),
                headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
                timeout=None,
            )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    @cached_property
    def documents(self) -> AsyncDocumentsClient:
        return AsyncDocumentsClient(environment=self._environment, api_key=self.api_key)

    @cached_property
    def model_versions(self) -> AsyncModelVersionsClient:
        return AsyncModelVersionsClient(environment=self._environment, api_key=self.api_key)

    @cached_property
    def sandboxes(self) -> AsyncSandboxesClient:
        return AsyncSandboxesClient(environment=self._environment, api_key=self.api_key)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LogprobsEnum(str, enum.Enum):
    ALL = "ALL"
    NONE = "NONE"

    def visit(self, all: typing.Callable[[], T_Result], none: typing.Callable[[], T_Result]) -> T_Result:
        if self is LogprobsEnum.ALL:
            return all()
        if self is LogprobsEnum.NONE:
            return none()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .model_version_sandbox_snapshot import ModelVersionSandboxSnapshot


class ModelVersionBuildConfig(pydantic.BaseModel):
    base_model: str = pydantic.Field(
        description=(
            "The name of the base model used to create this model version, as identified by the LLM provider.\n"
        )
    )
    sandbox_snapshot: typing.Optional[ModelVersionSandboxSnapshot] = pydantic.Field(
        description=(
            "Information about the sandbox snapshot that was used to create this model version, if applicable.\n"
        )
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .generate_result import GenerateResult


class GenerateResponse(pydantic.BaseModel):
    results: typing.List[GenerateResult]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    @property
    def texts(self) -> typing.List[str]:
        return [
            completion.text
            for result in self.results
            for completion in (result.data.completions if result.data else [])
        ]

    @property
    def text(self) -> str:
        if len(self.texts) != 1:
            raise ValueError(f"Expected exactly one completion, but got {len(self.texts)}")
        return self.texts[0]

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

import httpx
import pydantic

from ...core.api_error import ApiError
from ...core.jsonable_encoder import jsonable_encoder
from ...core.remove_none_from_headers import remove_none_from_headers
from ...environment import VellumEnvironment
from ...types.paginated_slim_document_list import PaginatedSlimDocumentList
from ...types.upload_document_response import UploadDocumentResponse


class DocumentsClient:
    def __init__(self, *, environment: VellumEnvironment = VellumEnvironment.PRODUCTION, api_key: str):
        self._environment = environment
        self.api_key = api_key

    def list(
        self,
        *,
        document_index_id: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        ordering: typing.Optional[str] = None,
    ) -> PaginatedSlimDocumentList:
        _response = httpx.request(
            "GET",
            urllib.parse.urljoin(f"{self._environment.default}/", "v1/documents"),
            params={"document_index_id": document_index_id, "limit": limit, "offset": offset, "ordering": ordering},
            headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(PaginatedSlimDocumentList, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def upload(
        self,
        *,
        add_to_index_names: typing.Optional[typing.List[str]] = None,
        external_id: typing.Optional[str] = None,
        label: str,
        contents: typing.IO,
        keywords: typing.Optional[typing.List[str]] = None,
    ) -> UploadDocumentResponse:
        _response = httpx.request(
            "POST",
            urllib.parse.urljoin(f"{self._environment.documents}/", "v1/upload-document"),
            data=jsonable_encoder(
                {
                    "add_to_index_names": add_to_index_names,
                    "external_id": external_id,
                    "label": label,
                    "keywords": keywords,
                }
            ),
            files={"contents": contents},
            headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(UploadDocumentResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncDocumentsClient:
    def __init__(self, *, environment: VellumEnvironment = VellumEnvironment.PRODUCTION, api_key: str):
        self._environment = environment
        self.api_key = api_key

    async def list(
        self,
        *,
        document_index_id: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        ordering: typing.Optional[str] = None,
    ) -> PaginatedSlimDocumentList:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "GET",
                urllib.parse.urljoin(f"{self._environment.default}/", "v1/documents"),
                params={"document_index_id": document_index_id, "limit": limit, "offset": offset, "ordering": ordering},
                headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
                timeout=None,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(PaginatedSlimDocumentList, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def upload(
        self,
        *,
        add_to_index_names: typing.Optional[typing.List[str]] = None,
        external_id: typing.Optional[str] = None,
        label: str,
        contents: typing.IO,
        keywords: typing.Optional[typing.List[str]] = None,
    ) -> UploadDocumentResponse:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "POST",
                urllib.parse.urljoin(f"{self._environment.documents}/", "v1/upload-document"),
                data=jsonable_encoder(
                    {
                        "add_to_index_names": add_to_index_names,
                        "external_id": external_id,
                        "label": label,
                        "keywords": keywords,
                    }
                ),
                files={"contents": contents},
                headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
                timeout=None,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(UploadDocumentResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .model_version_exec_config_parameters import ModelVersionExecConfigParameters
from .prompt_template_block_data import PromptTemplateBlockData


class ModelVersionExecConfigRead(pydantic.BaseModel):
    parameters: ModelVersionExecConfigParameters = pydantic.Field(
        description=("The generation parameters that are passed to the LLM provider at runtime.\n")
    )
    input_variables: typing.List[str] = pydantic.Field(
        description=("Names of the template variables specified in the prompt template.\n")
    )
    prompt_template: typing.Optional[str] = pydantic.Field(
        description=("The template used to generate prompts for this model version.\n")
    )
    prompt_block_data: typing.Optional[PromptTemplateBlockData]
    prompt_syntax_version: int

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime


class Document(pydantic.BaseModel):
    id: str = pydantic.Field(description=("The ID of the document.\n"))
    label: str = pydantic.Field(description=("The human-readable name for the document.\n"))
    external_id: typing.Optional[str] = pydantic.Field(
        description=(
            "The unique ID of the document as represented in an external system and specified when it was originally uploaded.\n"
        )
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ProviderEnum(str, enum.Enum):
    ANTHROPIC = "ANTHROPIC"
    COHERE = "COHERE"
    GOOGLE = "GOOGLE"
    HOSTED = "HOSTED"
    OPENAI = "OPENAI"
    PYQ = "PYQ"

    def visit(
        self,
        anthropic: typing.Callable[[], T_Result],
        cohere: typing.Callable[[], T_Result],
        google: typing.Callable[[], T_Result],
        hosted: typing.Callable[[], T_Result],
        openai: typing.Callable[[], T_Result],
        pyq: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ProviderEnum.ANTHROPIC:
            return anthropic()
        if self is ProviderEnum.COHERE:
            return cohere()
        if self is ProviderEnum.GOOGLE:
            return google()
        if self is ProviderEnum.HOSTED:
            return hosted()
        if self is ProviderEnum.OPENAI:
            return openai()
        if self is ProviderEnum.PYQ:
            return pyq()



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations


class VellumEnvironment:
    PRODUCTION: VellumEnvironment

    def __init__(self, *, default: str, predict: str, documents: str):
        self.default = default
        self.predict = predict
        self.documents = documents


VellumEnvironment.PRODUCTION = VellumEnvironment(
    default="https://api.vellum.ai", predict="https://predict.vellum.ai", documents="https://documents.vellum.ai"
)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .chat_message_request import ChatMessageRequest


class GenerateRequest(pydantic.BaseModel):
    input_values: typing.Dict[str, typing.Any] = pydantic.Field(
        description=("Key/value pairs for each template variable defined in the deployment's prompt.\n")
    )
    chat_history: typing.Optional[typing.List[ChatMessageRequest]] = pydantic.Field(
        description=(
            "Optionally provide a list of chat messages that'll be used in place of the special {$chat_history} variable, if included in the prompt.\n"
        )
    )
    external_ids: typing.Optional[typing.List[str]] = pydantic.Field(
        description=(
            "Optionally include a unique identifier for each generation, as represented outside of Vellum. Note that this should generally be a list of length one.\n"
        )
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class BlockTypeEnum(str, enum.Enum):
    CHAT_MESSAGE = "CHAT_MESSAGE"
    CHAT_HISTORY = "CHAT_HISTORY"
    JINJA = "JINJA"

    def visit(
        self,
        chat_message: typing.Callable[[], T_Result],
        chat_history: typing.Callable[[], T_Result],
        jinja: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is BlockTypeEnum.CHAT_MESSAGE:
            return chat_message()
        if self is BlockTypeEnum.CHAT_HISTORY:
            return chat_history()
        if self is BlockTypeEnum.JINJA:
            return jinja()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .document import Document


class SearchResult(pydantic.BaseModel):
    document: Document = pydantic.Field(
        description=("The document that contains the chunk that matched the search query.\n")
    )
    text: str = pydantic.Field(description=("The text of the chunk that matched the search query.\n"))
    keywords: typing.List[str]
    score: float = pydantic.Field(description=("A score representing how well the chunk matches the search query.\n"))

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ModelVersionReadStatusEnum(str, enum.Enum):
    CREATING = "CREATING"
    READY = "READY"
    CREATION_FAILED = "CREATION_FAILED"
    DISABLED = "DISABLED"

    def visit(
        self,
        creating: typing.Callable[[], T_Result],
        ready: typing.Callable[[], T_Result],
        creation_failed: typing.Callable[[], T_Result],
        disabled: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ModelVersionReadStatusEnum.CREATING:
            return creating()
        if self is ModelVersionReadStatusEnum.READY:
            return ready()
        if self is ModelVersionReadStatusEnum.CREATION_FAILED:
            return creation_failed()
        if self is ModelVersionReadStatusEnum.DISABLED:
            return disabled()



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

import httpx
import pydantic

from ...core.api_error import ApiError
from ...core.jsonable_encoder import jsonable_encoder
from ...core.remove_none_from_headers import remove_none_from_headers
from ...environment import VellumEnvironment
from ...types.sandbox_input_request import SandboxInputRequest
from ...types.sandbox_metric_input_params_request import SandboxMetricInputParamsRequest
from ...types.sandbox_scenario import SandboxScenario


class SandboxesClient:
    def __init__(self, *, environment: VellumEnvironment = VellumEnvironment.PRODUCTION, api_key: str):
        self._environment = environment
        self.api_key = api_key

    def upsert_sandbox_scenario(
        self,
        id: str,
        *,
        label: typing.Optional[str] = None,
        inputs: typing.List[SandboxInputRequest],
        scenario_id: typing.Optional[str] = None,
        metric_input_params: typing.Optional[SandboxMetricInputParamsRequest] = None,
    ) -> SandboxScenario:
        _response = httpx.request(
            "POST",
            urllib.parse.urljoin(f"{self._environment.default}/", f"v1/sandboxes/{id}/scenarios"),
            json=jsonable_encoder(
                {
                    "label": label,
                    "inputs": inputs,
                    "scenario_id": scenario_id,
                    "metric_input_params": metric_input_params,
                }
            ),
            headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(SandboxScenario, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncSandboxesClient:
    def __init__(self, *, environment: VellumEnvironment = VellumEnvironment.PRODUCTION, api_key: str):
        self._environment = environment
        self.api_key = api_key

    async def upsert_sandbox_scenario(
        self,
        id: str,
        *,
        label: typing.Optional[str] = None,
        inputs: typing.List[SandboxInputRequest],
        scenario_id: typing.Optional[str] = None,
        metric_input_params: typing.Optional[SandboxMetricInputParamsRequest] = None,
    ) -> SandboxScenario:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "POST",
                urllib.parse.urljoin(f"{self._environment.default}/", f"v1/sandboxes/{id}/scenarios"),
                json=jsonable_encoder(
                    {
                        "label": label,
                        "inputs": inputs,
                        "scenario_id": scenario_id,
                        "metric_input_params": metric_input_params,
                    }
                ),
                headers=remove_none_from_headers({"X_API_KEY": self.api_key}),
                timeout=None,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(SandboxScenario, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ProcessingStateEnum(str, enum.Enum):
    QUEUED = "QUEUED"
    PROCESSING = "PROCESSING"
    PROCESSED = "PROCESSED"
    FAILED = "FAILED"

    def visit(
        self,
        queued: typing.Callable[[], T_Result],
        processing: typing.Callable[[], T_Result],
        processed: typing.Callable[[], T_Result],
        failed: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ProcessingStateEnum.QUEUED:
            return queued()
        if self is ProcessingStateEnum.PROCESSING:
            return processing()
        if self is ProcessingStateEnum.PROCESSED:
            return processed()
        if self is ProcessingStateEnum.FAILED:
            return failed()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class FinishReasonEnum(str, enum.Enum):
    LENGTH = "LENGTH"
    STOP = "STOP"
    UNKNOWN = "UNKNOWN"

    def visit(
        self,
        length: typing.Callable[[], T_Result],
        stop: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is FinishReasonEnum.LENGTH:
            return length()
        if self is FinishReasonEnum.STOP:
            return stop()
        if self is FinishReasonEnum.UNKNOWN:
            return unknown()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .document_document_to_document_index import DocumentDocumentToDocumentIndex
from .processing_state_enum import ProcessingStateEnum
from .slim_document_status_enum import SlimDocumentStatusEnum


class SlimDocument(pydantic.BaseModel):
    id: str = pydantic.Field(description=("Vellum-generated ID that uniquely identifies this document.\n"))
    external_id: typing.Optional[str] = pydantic.Field(
        description=("The external ID that was originally provided when uploading the document.\n")
    )
    last_uploaded_at: str = pydantic.Field(
        description=("A timestamp representing when this document was most recently uploaded.\n")
    )
    label: str = pydantic.Field(description=("Human-friendly name for this document.\n"))
    processing_state: typing.Optional[ProcessingStateEnum] = pydantic.Field(
        description=("The current processing state of the document\n")
    )
    status: typing.Optional[SlimDocumentStatusEnum] = pydantic.Field(description=("The document's current status.\n"))
    keywords: typing.Optional[typing.List[str]] = pydantic.Field(
        description=(
            "A list of keywords associated with this document. Originally provided when uploading the document.\n"
        )
    )
    document_to_document_indexes: typing.List[DocumentDocumentToDocumentIndex]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime


class SubmitCompletionActualRequest(pydantic.BaseModel):
    id: typing.Optional[str] = pydantic.Field(
        description=(
            "The Vellum-generated ID of a previously generated completion. Must provide either this or external_id.\n"
        )
    )
    external_id: typing.Optional[str] = pydantic.Field(
        description=(
            "The external ID that was originally provided when generating the completion that you'd now like to submit actuals for. Must provide either this or id.\n"
        )
    )
    text: typing.Optional[str] = pydantic.Field(
        description=("Text representing what the completion _should_ have been.\n")
    )
    quality: typing.Optional[float] = pydantic.Field(
        description=(
            "A number between 0 and 1 representing the quality of the completion. 0 is the worst, 1 is the best.\n"
        )
    )
    timestamp: typing.Optional[str] = pydantic.Field(
        description=(
            "Optionally provide the timestamp representing when this feedback was collected. Used for reporting purposes.\n"
        )
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .search_filters_request import SearchFiltersRequest
from .search_result_merging_request import SearchResultMergingRequest
from .search_weights_request import SearchWeightsRequest


class SearchRequestOptionsRequest(pydantic.BaseModel):
    limit: typing.Optional[int] = pydantic.Field(description=("The maximum number of results to return.\n"))
    weights: typing.Optional[SearchWeightsRequest] = pydantic.Field(
        description=("The weights to use for the search. Must add up to 1.0.\n")
    )
    result_merging: typing.Optional[SearchResultMergingRequest] = pydantic.Field(
        description=("The configuration for merging results.\n")
    )
    filters: typing.Optional[SearchFiltersRequest] = pydantic.Field(
        description=("The filters to apply to the search.\n")
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SlimDocumentStatusEnum(str, enum.Enum):
    ACTIVE = "ACTIVE"

    def visit(self, active: typing.Callable[[], T_Result]) -> T_Result:
        if self is SlimDocumentStatusEnum.ACTIVE:
            return active()



# This file was auto-generated by Fern from our API Definition.

from .environment import VellumEnvironment
from .resources import documents, model_versions, sandboxes
from .types import (
    BlockTypeEnum,
    ChatMessage,
    ChatMessageRequest,
    ChatMessageRole,
    Document,
    DocumentDocumentToDocumentIndex,
    EnrichedNormalizedCompletion,
    FinishReasonEnum,
    GenerateErrorResponse,
    GenerateOptionsRequest,
    GenerateRequest,
    GenerateResponse,
    GenerateResult,
    GenerateResultData,
    GenerateResultError,
    IndexingStateEnum,
    LogprobsEnum,
    ModelTypeEnum,
    ModelVersionBuildConfig,
    ModelVersionExecConfigParameters,
    ModelVersionExecConfigRead,
    ModelVersionRead,
    ModelVersionReadStatusEnum,
    ModelVersionSandboxSnapshot,
    NormalizedLogProbs,
    NormalizedTokenLogProbs,
    PaginatedSlimDocumentList,
    ProcessingStateEnum,
    PromptTemplateBlock,
    PromptTemplateBlockData,
    PromptTemplateBlockProperties,
    ProviderEnum,
    SandboxInput,
    SandboxInputRequest,
    SandboxMetricInputParams,
    SandboxMetricInputParamsRequest,
    SandboxScenario,
    SearchErrorResponse,
    SearchFiltersRequest,
    SearchRequestOptionsRequest,
    SearchResponse,
    SearchResult,
    SearchResultMergingRequest,
    SearchWeightsRequest,
    SlimDocument,
    SlimDocumentStatusEnum,
    SubmitCompletionActualRequest,
    SubmitCompletionActualsErrorResponse,
    TypeEnum,
    UploadDocumentErrorResponse,
    UploadDocumentResponse,
)

__all__ = [
    "BlockTypeEnum",
    "ChatMessage",
    "ChatMessageRequest",
    "ChatMessageRole",
    "Document",
    "DocumentDocumentToDocumentIndex",
    "EnrichedNormalizedCompletion",
    "FinishReasonEnum",
    "GenerateErrorResponse",
    "GenerateOptionsRequest",
    "GenerateRequest",
    "GenerateResponse",
    "GenerateResult",
    "GenerateResultData",
    "GenerateResultError",
    "IndexingStateEnum",
    "LogprobsEnum",
    "ModelTypeEnum",
    "ModelVersionBuildConfig",
    "ModelVersionExecConfigParameters",
    "ModelVersionExecConfigRead",
    "ModelVersionRead",
    "ModelVersionReadStatusEnum",
    "ModelVersionSandboxSnapshot",
    "NormalizedLogProbs",
    "NormalizedTokenLogProbs",
    "PaginatedSlimDocumentList",
    "ProcessingStateEnum",
    "PromptTemplateBlock",
    "PromptTemplateBlockData",
    "PromptTemplateBlockProperties",
    "ProviderEnum",
    "SandboxInput",
    "SandboxInputRequest",
    "SandboxMetricInputParams",
    "SandboxMetricInputParamsRequest",
    "SandboxScenario",
    "SearchErrorResponse",
    "SearchFiltersRequest",
    "SearchRequestOptionsRequest",
    "SearchResponse",
    "SearchResult",
    "SearchResultMergingRequest",
    "SearchWeightsRequest",
    "SlimDocument",
    "SlimDocumentStatusEnum",
    "SubmitCompletionActualRequest",
    "SubmitCompletionActualsErrorResponse",
    "TypeEnum",
    "UploadDocumentErrorResponse",
    "UploadDocumentResponse",
    "VellumEnvironment",
    "documents",
    "model_versions",
    "sandboxes",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class IndexingStateEnum(str, enum.Enum):
    AWAITING_PROCESSING = "AWAITING_PROCESSING"
    QUEUED = "QUEUED"
    INDEXING = "INDEXING"
    INDEXED = "INDEXED"
    FAILED = "FAILED"

    def visit(
        self,
        awaiting_processing: typing.Callable[[], T_Result],
        queued: typing.Callable[[], T_Result],
        indexing: typing.Callable[[], T_Result],
        indexed: typing.Callable[[], T_Result],
        failed: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is IndexingStateEnum.AWAITING_PROCESSING:
            return awaiting_processing()
        if self is IndexingStateEnum.QUEUED:
            return queued()
        if self is IndexingStateEnum.INDEXING:
            return indexing()
        if self is IndexingStateEnum.INDEXED:
            return indexed()
        if self is IndexingStateEnum.FAILED:
            return failed()



# This file was auto-generated by Fern from our API Definition.

from .block_type_enum import BlockTypeEnum
from .chat_message import ChatMessage
from .chat_message_request import ChatMessageRequest
from .chat_message_role import ChatMessageRole
from .document import Document
from .document_document_to_document_index import DocumentDocumentToDocumentIndex
from .enriched_normalized_completion import EnrichedNormalizedCompletion
from .finish_reason_enum import FinishReasonEnum
from .generate_error_response import GenerateErrorResponse
from .generate_options_request import GenerateOptionsRequest
from .generate_request import GenerateRequest
from .generate_response import GenerateResponse
from .generate_result import GenerateResult
from .generate_result_data import GenerateResultData
from .generate_result_error import GenerateResultError
from .indexing_state_enum import IndexingStateEnum
from .logprobs_enum import LogprobsEnum
from .model_type_enum import ModelTypeEnum
from .model_version_build_config import ModelVersionBuildConfig
from .model_version_exec_config_parameters import ModelVersionExecConfigParameters
from .model_version_exec_config_read import ModelVersionExecConfigRead
from .model_version_read import ModelVersionRead
from .model_version_read_status_enum import ModelVersionReadStatusEnum
from .model_version_sandbox_snapshot import ModelVersionSandboxSnapshot
from .normalized_log_probs import NormalizedLogProbs
from .normalized_token_log_probs import NormalizedTokenLogProbs
from .paginated_slim_document_list import PaginatedSlimDocumentList
from .processing_state_enum import ProcessingStateEnum
from .prompt_template_block import PromptTemplateBlock
from .prompt_template_block_data import PromptTemplateBlockData
from .prompt_template_block_properties import PromptTemplateBlockProperties
from .provider_enum import ProviderEnum
from .sandbox_input import SandboxInput
from .sandbox_input_request import SandboxInputRequest
from .sandbox_metric_input_params import SandboxMetricInputParams
from .sandbox_metric_input_params_request import SandboxMetricInputParamsRequest
from .sandbox_scenario import SandboxScenario
from .search_error_response import SearchErrorResponse
from .search_filters_request import SearchFiltersRequest
from .search_request_options_request import SearchRequestOptionsRequest
from .search_response import SearchResponse
from .search_result import SearchResult
from .search_result_merging_request import SearchResultMergingRequest
from .search_weights_request import SearchWeightsRequest
from .slim_document import SlimDocument
from .slim_document_status_enum import SlimDocumentStatusEnum
from .submit_completion_actual_request import SubmitCompletionActualRequest
from .submit_completion_actuals_error_response import SubmitCompletionActualsErrorResponse
from .type_enum import TypeEnum
from .upload_document_error_response import UploadDocumentErrorResponse
from .upload_document_response import UploadDocumentResponse

__all__ = [
    "BlockTypeEnum",
    "ChatMessage",
    "ChatMessageRequest",
    "ChatMessageRole",
    "Document",
    "DocumentDocumentToDocumentIndex",
    "EnrichedNormalizedCompletion",
    "FinishReasonEnum",
    "GenerateErrorResponse",
    "GenerateOptionsRequest",
    "GenerateRequest",
    "GenerateResponse",
    "GenerateResult",
    "GenerateResultData",
    "GenerateResultError",
    "IndexingStateEnum",
    "LogprobsEnum",
    "ModelTypeEnum",
    "ModelVersionBuildConfig",
    "ModelVersionExecConfigParameters",
    "ModelVersionExecConfigRead",
    "ModelVersionRead",
    "ModelVersionReadStatusEnum",
    "ModelVersionSandboxSnapshot",
    "NormalizedLogProbs",
    "NormalizedTokenLogProbs",
    "PaginatedSlimDocumentList",
    "ProcessingStateEnum",
    "PromptTemplateBlock",
    "PromptTemplateBlockData",
    "PromptTemplateBlockProperties",
    "ProviderEnum",
    "SandboxInput",
    "SandboxInputRequest",
    "SandboxMetricInputParams",
    "SandboxMetricInputParamsRequest",
    "SandboxScenario",
    "SearchErrorResponse",
    "SearchFiltersRequest",
    "SearchRequestOptionsRequest",
    "SearchResponse",
    "SearchResult",
    "SearchResultMergingRequest",
    "SearchWeightsRequest",
    "SlimDocument",
    "SlimDocumentStatusEnum",
    "SubmitCompletionActualRequest",
    "SubmitCompletionActualsErrorResponse",
    "TypeEnum",
    "UploadDocumentErrorResponse",
    "UploadDocumentResponse",
]
